# Generated by Django 2.2.6 on 2019-11-13 13:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0026_scmsteprun_step_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='scmpipelinerun',
            name='first_parent_hash',
            field=models.CharField(blank=True, help_text='Commit hash of first parent commit, to determine order of commits. First commit has none.', max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name='scmpipelinerun',
            name='status',
            field=models.CharField(choices=[('initializing', 'initializing'), ('queued', 'queued'), ('in progress', 'in progress'), ('failed', 'failed'), ('success', 'success'), ('skipped', 'skipped')], default='initializing', max_length=30),
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-08 08:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0019_scmsteprun_sequence_id'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scmrelease',
            name='scm_pipeline_run',
        ),
        migrations.AddField(
            model_name='scmrelease',
            name='scm_pipeline_runs',
            field=models.ManyToManyField(to='katka.SCMPipelineRun'),
        ),
        migrations.AddField(
            model_name='scmrelease',
            name='status',
            field=models.CharField(choices=[('open', 'open'), ('closed', 'closed')], default='open', max_length=30),
        ),
    ]



from katka.fields import username_on_model
from rest_framework import mixins, status
from rest_framework.response import Response
from rest_framework.viewsets import GenericViewSet


class ReadOnlyAuditViewMixin(mixins.RetrieveModelMixin,
                             mixins.ListModelMixin,
                             GenericViewSet):
    model = None

    def get_queryset(self):
        return self.model.objects.exclude(deleted=True)


class UpdateAuditMixin(mixins.UpdateModelMixin, GenericViewSet):

    def update(self, request, *args, **kwargs):
        with username_on_model(self.model, request.user.username):
            return super().update(request, *args, **kwargs)


class AuditViewSet(mixins.CreateModelMixin,
                   UpdateAuditMixin,
                   mixins.DestroyModelMixin,
                   ReadOnlyAuditViewMixin):

    def create(self, request, *args, **kwargs):
        with username_on_model(self.model, request.user.username):
            return super().create(request, *args, **kwargs)

    def destroy(self, request, *args, **kwargs):
        instance = self.get_object()
        instance.deleted = True

        with username_on_model(self.model, request.user.username):
            instance.save()

        return Response(status=status.HTTP_204_NO_CONTENT)


class FilterViewMixin:
    parameter_lookup_map = None

    """
    Uses the Serializer fields to construct GET Parameter filtering
    """
    def get_queryset(self):
        queryset = super().get_queryset()

        # Fetch distinct for all model fields, to prevent duplications due to SQL Joins
        queryset = queryset.distinct()

        # Allow filtering on related fields in serializer
        related_fields = self.serializer_class.get_related_fields()
        filter_fields_lookup = {field: field for field in related_fields}
        filter_fields_keys = [field for field in related_fields]

        # Also support a mapping from query parameter to django query field
        if self.parameter_lookup_map:
            filter_fields_keys += self.parameter_lookup_map.keys()
            filter_fields_lookup.update(self.parameter_lookup_map)

        # Loop through the keys to maintain proper order
        filters = {}
        for query_param in filter_fields_keys:
            django_lookup_field = filter_fields_lookup[query_param]
            value = self.request.query_params.get(query_param, None)
            if value is not None:
                filters[django_lookup_field] = value

        if filters:
            queryset = queryset.filter(**filters)

        return queryset



# Generated by Django 2.1.7 on 2019-02-22 03:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0009_scmsteprun'),
    ]

    operations = [
        migrations.RenameField(
            model_name='scmservice',
            old_name='type',
            new_name='scm_service_type',
        ),
    ]



import logging
from datetime import datetime

from django.conf import settings

import pytz
from katka.constants import (
    PIPELINE_FINAL_STATUSES, PIPELINE_STATUS_IN_PROGRESS, PIPELINE_STATUS_INITIALIZING, PIPELINE_STATUS_QUEUED,
    STEP_FINAL_STATUSES,
)
from katka.models import (
    Application, ApplicationMetadata, Credential, CredentialSecret, Project, SCMPipelineRun, SCMRelease, SCMRepository,
    SCMService, SCMStepRun, Team,
)
from katka.serializers import (
    ApplicationMetadataSerializer, ApplicationSerializer, CredentialSecretSerializer, CredentialSerializer,
    ProjectSerializer, SCMPipelineRunSerializer, SCMReleaseSerializer, SCMRepositorySerializer, SCMServiceSerializer,
    SCMStepRunSerializer, SCMStepRunUpdateSerializer, TeamSerializer,
)
from katka.viewsets import AuditViewSet, FilterViewMixin, ReadOnlyAuditViewMixin, UpdateAuditMixin
from rest_framework.permissions import IsAuthenticated

log = logging.getLogger(__name__)


class TeamViewSet(FilterViewMixin, AuditViewSet):
    model = Team
    serializer_class = TeamSerializer
    lookup_field = 'public_identifier'
    lookup_value_regex = '[0-9a-f-]{36}'

    def get_queryset(self):
        # Only show teams that are linked to a group that the user is part of
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(group__in=user_groups)


class ProjectViewSet(FilterViewMixin, AuditViewSet):
    model = Project
    serializer_class = ProjectSerializer

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(team__group__in=user_groups)


class ApplicationViewSet(FilterViewMixin, AuditViewSet):
    model = Application
    serializer_class = ApplicationSerializer

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(project__team__group__in=user_groups)


class CredentialViewSet(FilterViewMixin, AuditViewSet):
    model = Credential
    serializer_class = CredentialSerializer

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(team__group__in=user_groups)


class CredentialSecretsViewSet(AuditViewSet):
    model = CredentialSecret
    serializer_class = CredentialSecretSerializer
    lookup_field = 'key'

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        kwargs = {
            'credential__team__group__in': user_groups,
            'credential__deleted': False,
            'credential': self.kwargs['credentials_pk'],
        }
        return super().get_queryset().filter(**kwargs)


class SCMServiceViewSet(ReadOnlyAuditViewMixin):
    model = SCMService
    serializer_class = SCMServiceSerializer
    permission_classes = [IsAuthenticated]


class SCMRepositoryViewSet(FilterViewMixin, AuditViewSet):
    model = SCMRepository
    serializer_class = SCMRepositorySerializer

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(credential__team__group__in=user_groups)


class SCMPipelineRunViewSet(FilterViewMixin, AuditViewSet):
    model = SCMPipelineRun
    serializer_class = SCMPipelineRunSerializer

    parameter_lookup_map = {
        'scmrelease': 'scmrelease',
        'release': 'scmrelease',
    }

    def perform_update(self, serializer):
        status = serializer.validated_data.get('status', None)
        if status == PIPELINE_STATUS_IN_PROGRESS:
            if not self._ready_to_run(serializer.instance.application, serializer.instance.first_parent_hash):
                serializer.validated_data['status'] = PIPELINE_STATUS_QUEUED

        super().perform_update(serializer)

        if status in PIPELINE_FINAL_STATUSES:
            self._run_next_pipeline_if_available(serializer.instance.application, serializer.instance.commit_hash)

    def _ready_to_run(self, application, parent_hash):
        if parent_hash is None:
            return True  # this is probably the first commit

        try:
            parent_instance = self.model.objects.get(application=application, commit_hash=parent_hash)
        except self.model.DoesNotExist:
            self._trigger_sync()
            return False  # parent commit does not exist, we need a sync before we can continue

        if parent_instance.status not in PIPELINE_FINAL_STATUSES:
            return False  # exists, but not ready to run this one yet

        return True

    def _run_next_pipeline_if_available(self, application, commit_hash):
        try:
            next_pipeline = self.model.objects.get(application=application, first_parent_hash=commit_hash)
        except self.model.DoesNotExist:
            return  # does not exist (yet), so nothing to do

        if next_pipeline.status != PIPELINE_STATUS_QUEUED:
            if next_pipeline.status != PIPELINE_STATUS_INITIALIZING:
                log.warning(
                    f'Next pipeline {next_pipeline.pk} is not queued, it has status "{next_pipeline.status}", '
                    'not updating'
                )
            return

        # No need to wrap inside a "with username_on_model():" context manager since at this point we already
        # are in a context. Worried about infinite recursion because we keep setting statuses for the next
        # pipelines? Since this method is only called when a pipeline moves from the "in progress" state to
        # a final state and the next pipeline is set to the "in progress" state, it should not trigger recursion.
        next_pipeline.status = PIPELINE_STATUS_IN_PROGRESS
        next_pipeline.save()

    def _trigger_sync(self):
        """We are missing commits, sync them so we can get the complete string of commits"""
        log.warning("Need to sync commits because at least one is missing, but this is not implemented yet")

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(application__project__team__group__in=user_groups)


def pre_validate_steprun_update(serializer):
    """In case of an update to the status which sets the step to a final status, ensure the 'ended_at'
       field is set.
    """
    if 'status' in serializer.validated_data and serializer.validated_data['status'] in STEP_FINAL_STATUSES \
            and 'ended_at' not in serializer.validated_data:
        serializer.validated_data['ended_at'] = datetime.now(tz=pytz.timezone(settings.TIME_ZONE))


class SCMStepRunViewSet(FilterViewMixin, AuditViewSet):
    model = SCMStepRun
    serializer_class = SCMStepRunSerializer

    def perform_update(self, serializer):
        pre_validate_steprun_update(serializer)
        serializer.save()

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(scm_pipeline_run__application__project__team__group__in=user_groups)


class SCMStepRunUpdateStatusView(UpdateAuditMixin):
    model = SCMStepRun
    serializer_class = SCMStepRunUpdateSerializer

    def perform_update(self, serializer):
        pre_validate_steprun_update(serializer)
        serializer.save()

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return self.model.objects.exclude(deleted=True).filter(
            scm_pipeline_run__application__project__team__group__in=user_groups
        )


class SCMReleaseViewSet(FilterViewMixin, ReadOnlyAuditViewMixin):
    model = SCMRelease
    serializer_class = SCMReleaseSerializer

    parameter_lookup_map = {
        'application': 'scm_pipeline_runs__application'
    }

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        return super().get_queryset().filter(
            scm_pipeline_runs__application__project__team__group__in=user_groups
        ).order_by("-created_at")


class ApplicationMetadataViewSet(AuditViewSet):
    model = ApplicationMetadata
    serializer_class = ApplicationMetadataSerializer
    lookup_field = 'key'

    def get_queryset(self):
        user_groups = self.request.user.groups.all()
        kwargs = {
            'application__project__team__group__in': user_groups,
            'application__deleted': False,
            'application': self.kwargs['applications_pk'],
            'deleted': False,
        }
        return super().get_queryset().filter(**kwargs)



# Status is not in the model to allow usage in different models
PIPELINE_STATUS_INITIALIZING = 'initializing'
PIPELINE_STATUS_QUEUED = 'queued'
PIPELINE_STATUS_IN_PROGRESS = 'in progress'
PIPELINE_STATUS_FAILED = 'failed'
PIPELINE_STATUS_SUCCESS = 'success'
PIPELINE_STATUS_SKIPPED = 'skipped'

PIPELINE_STATUS_CHOICES = (
    (PIPELINE_STATUS_INITIALIZING, PIPELINE_STATUS_INITIALIZING),
    (PIPELINE_STATUS_QUEUED, PIPELINE_STATUS_QUEUED),
    (PIPELINE_STATUS_IN_PROGRESS, PIPELINE_STATUS_IN_PROGRESS),
    (PIPELINE_STATUS_FAILED, PIPELINE_STATUS_FAILED),
    (PIPELINE_STATUS_SUCCESS, PIPELINE_STATUS_SUCCESS),
    (PIPELINE_STATUS_SKIPPED, PIPELINE_STATUS_SKIPPED),
)

PIPELINE_FINAL_STATUSES = (
    PIPELINE_STATUS_SUCCESS,
    PIPELINE_STATUS_FAILED,
)

STEP_STATUS_NOT_STARTED = 'not started'
STEP_STATUS_IN_PROGRESS = 'in progress'
STEP_STATUS_WAITING = 'waiting'  # A step cannot proceed until some action is completed
STEP_STATUS_SKIPPED = 'skipped'  # A step is skipped due to some conditional
STEP_STATUS_FAILED = 'failed'
STEP_STATUS_SUCCESS = 'success'

STEP_STATUS_CHOICES = (
    (STEP_STATUS_NOT_STARTED, STEP_STATUS_NOT_STARTED),
    (STEP_STATUS_IN_PROGRESS, STEP_STATUS_IN_PROGRESS),
    (STEP_STATUS_WAITING, STEP_STATUS_WAITING),
    (STEP_STATUS_SKIPPED, STEP_STATUS_SKIPPED),
    (STEP_STATUS_FAILED, STEP_STATUS_FAILED),
    (STEP_STATUS_SUCCESS, STEP_STATUS_SUCCESS),
)

STEP_FINAL_STATUSES = (STEP_STATUS_SKIPPED, STEP_STATUS_FAILED, STEP_STATUS_SUCCESS)
STEP_EXECUTED_STATUSES = (STEP_STATUS_FAILED, STEP_STATUS_SUCCESS)


RELEASE_STATUS_IN_PROGRESS = 'in progress'
RELEASE_STATUS_FAILED = 'failed'
RELEASE_STATUS_SUCCESS = 'success'

RELEASE_STATUS_CHOICES = (
    (RELEASE_STATUS_IN_PROGRESS, RELEASE_STATUS_IN_PROGRESS),
    (RELEASE_STATUS_FAILED, RELEASE_STATUS_FAILED),
    (RELEASE_STATUS_SUCCESS, RELEASE_STATUS_SUCCESS),
)

TAG_PRODUCTION_CHANGE_STARTED = "production_change_start"
TAG_PRODUCTION_CHANGE_ENDED = "production_change_end"



# Generated by Django 2.2.7 on 2019-11-05 10:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0024_scmsteprun_started_ended'),
    ]

    operations = [
        migrations.RenameField(
            model_name='application',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='application',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='applicationmetadata',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='applicationmetadata',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='credential',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='credential',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='credentialsecret',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='credentialsecret',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='project',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='project',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='scmpipelinerun',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='scmpipelinerun',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='scmrelease',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='scmrelease',
            old_name='ended',
            new_name='ended_at',
        ),
        migrations.RenameField(
            model_name='scmrelease',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='scmrelease',
            old_name='started',
            new_name='started_at',
        ),
        migrations.RenameField(
            model_name='scmrepository',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='scmrepository',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='scmservice',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='scmservice',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='scmsteprun',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='scmsteprun',
            old_name='ended',
            new_name='ended_at',
        ),
        migrations.RenameField(
            model_name='scmsteprun',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='team',
            old_name='created',
            new_name='created_at',
        ),
        migrations.RenameField(
            model_name='team',
            old_name='modified',
            new_name='modified_at',
        ),
        migrations.RenameField(
            model_name='scmsteprun',
            old_name='started',
            new_name='started_at',
        ),
    ]



import json
import logging
from dataclasses import dataclass
from datetime import datetime

from katka import constants
from katka.fields import username_on_model
from katka.models import SCMPipelineRun, SCMRelease, SCMStepRun

log = logging.getLogger('katka')


@dataclass
class StepsPreConditions:
    version_number: str
    success_status_between_start_end: list
    prod_change_start_date: datetime = None
    prod_change_end_date: datetime = None

    @property
    def all_status_between_start_and_finish_are_success(self):
        return all(self.success_status_between_start_end)

    @property
    def start_and_finish_tags_were_executed(self):
        return self.prod_change_start_date is not None and self.prod_change_end_date is not None


def create_release_if_necessary(pipeline):
    release = _get_current_release(pipeline)
    with username_on_model(SCMRelease, pipeline.modified_username):
        if release is None:
            release = SCMRelease.objects.create()

        release.scm_pipeline_runs.add(pipeline)
        release.save()


def close_release_if_pipeline_finished(pipeline: SCMPipelineRun):
    if pipeline.status not in constants.PIPELINE_FINAL_STATUSES:
        log.debug(f'Pipeline {pipeline.public_identifier} not finished, doing nothing')
        return None

    pre_conditions = _gather_steps_pre_conditions(pipeline)
    if not pre_conditions.start_and_finish_tags_were_executed:
        log.debug(f'Pipeline {pipeline.public_identifier} missing start and/or finish tags')
        return None

    if not pre_conditions.version_number:
        log.debug(f'Pipeline {pipeline.public_identifier} missing release version')
        return None

    release = _get_current_release(pipeline)
    if release and pre_conditions.all_status_between_start_and_finish_are_success:
        release.status = constants.RELEASE_STATUS_SUCCESS
    elif release:
        log.debug(f'Pipeline {pipeline.public_identifier} contains step(s) with failed status')
        release.status = constants.RELEASE_STATUS_FAILED
    else:
        log.warning(f'No open release for pipeline {pipeline.public_identifier}')

    with username_on_model(SCMRelease, pipeline.modified_username):
        if release:
            release.name = pre_conditions.version_number
            release.started_at = pre_conditions.prod_change_start_date
            release.ended_at = pre_conditions.prod_change_end_date
            release.save()

    return release.status if release else None


def _gather_steps_pre_conditions(pipeline):
    steps = SCMStepRun.objects.filter(scm_pipeline_run=pipeline).order_by("sequence_id")
    prod_start_date = None
    prod_end_date = None
    success_status_between_start_end = []
    pipeline_output = {}
    for step in steps:
        if step.status not in constants.STEP_EXECUTED_STATUSES:
            continue
        _add_output(pipeline_output=pipeline_output, step_output=step.output)
        if constants.TAG_PRODUCTION_CHANGE_STARTED in step.tags.split(" "):
            prod_start_date = step.started_at

        if prod_start_date is not None:
            success_status_between_start_end.append(step.status == constants.STEP_STATUS_SUCCESS)

        if constants.TAG_PRODUCTION_CHANGE_ENDED in step.tags.split(" "):
            prod_end_date = step.ended_at
            break

    return StepsPreConditions(pipeline_output.get("release.version"),
                              success_status_between_start_end,
                              prod_change_start_date=prod_start_date,
                              prod_change_end_date=prod_end_date)


def _add_output(pipeline_output: dict, step_output: str) -> None:
    if not step_output:
        return
    try:
        pipeline_output.update(json.loads(step_output))
    except json.JSONDecodeError:
        logging.warning("Invalid JSON in step output")


def _get_current_release(pipeline):
    releases = SCMRelease.objects.filter(
        status=constants.RELEASE_STATUS_IN_PROGRESS, scm_pipeline_runs__application=pipeline.application
    )
    release = None
    if len(releases) == 0:
        log.error(f'No open releases found for application {pipeline.application.pk}')
    elif len(releases) > 1:
        log.error(f'Multiple open releases found for application {pipeline.application.pk}, picking newest')
        release = releases.order_by('-created_at').first()
    else:
        release = releases[0]
    return release



# Generated by Django 2.2.6 on 2019-10-24 08:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0022_change_release_status_fields'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scmrelease',
            name='from_hash',
        ),
        migrations.RemoveField(
            model_name='scmrelease',
            name='released',
        ),
        migrations.RemoveField(
            model_name='scmrelease',
            name='to_hash',
        ),
        migrations.AddField(
            model_name='scmrelease',
            name='ended',
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name='scmrelease',
            name='started',
            field=models.DateTimeField(null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2019-02-19 07:13

import uuid

import django.db.models.deletion
from django.db import migrations, models

import katka.fields


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0007_remove_status_add_deleted'),
    ]

    operations = [
        migrations.CreateModel(
            name='SCMPipelineRun',
            fields=[
                ('created', models.DateTimeField(auto_now_add=True)),
                ('created_username', katka.fields.AutoUsernameField(max_length=50)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('modified_username', katka.fields.AutoUsernameField(max_length=50)),
                ('deleted', models.BooleanField(default=False)),
                ('public_identifier', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('commit_hash', models.CharField(max_length=64)),
                ('status', models.CharField(choices=[('failed', 'failed'), ('success', 'success'), ('in progress', 'in progress')], default='in progress', max_length=30)),
                ('steps_total', models.PositiveSmallIntegerField()),
                ('steps_completed', models.PositiveSmallIntegerField(default=0)),
                ('pipeline_yaml', models.TextField()),
                ('application', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='katka.Application')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 2.1.5 on 2019-05-07 01:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('katka', '0018_auto_20190506_0425'),
    ]

    operations = [
        migrations.AddField(
            model_name='scmsteprun',
            name='sequence_id',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
    ]




from setuptools import setup
setup(**{'author': 'D-Nitro',
 'author_email': 'd-nitro@kpn.com',
 'classifiers': ['Development Status :: 3 - Alpha',
                 'Framework :: Django :: 2.1',
                 'Intended Audience :: Developers',
                 'Natural Language :: English',
                 'Operating System :: OS Independent',
                 'Programming Language :: Python :: 3.7',
                 'Topic :: Internet :: WWW/HTTP'],
 'description': 'Katka Django core application',
 'include_package_data': True,
 'install_requires': ['Django<3.0,>=2.1',
                      'djangorestframework<4.0.0,>=3.9.0',
                      'django-encrypted-model-fields<1.0.0,>=0.5.8',
                      'drf-nested-routers'],
 'long_description': '# Katka core\n'
                     '\n'
                     'Django app which is be responsible for storing '
                     'information abouts applications and teams.\n'
                     '\n'
                     '## Clone\n'
                     'You can clone this repository on: '
                     'https://github.com/kpn/katka-core\n'
                     '\n'
                     '## Setup\n'
                     'Setup your environment:\n'
                     '\n'
                     '```shell\n'
                     '$ make venv\n'
                     '```\n'
                     '\n'
                     '## Stack\n'
                     '\n'
                     'Katka core is built on top of the Python framework '
                     'Django and the Django Rest\n'
                     'Framework to build APIs. Under the hood it runs Python '
                     '3.7.\n'
                     '\n'
                     '### Dependencies\n'
                     '* [djangorestframework](djangorestframework): django '
                     'toolkit for building Web APIs\n'
                     '* '
                     '[django-encrypted-model-fields](django-encrypted-model-fields): '
                     'save encrypted fields on DB\n'
                     '\n'
                     '[djangorestframework]: '
                     'https://github.com/encode/django-rest-framework\n'
                     '[django-encrypted-model-fields]: '
                     'https://gitlab.com/lansharkconsulting/django/django-encrypted-model-fields/\n'
                     '\n'
                     '## Contributing\n'
                     '\n'
                     '### Workflow\n'
                     '1. Fork this repository\n'
                     '2. Clone your fork\n'
                     '3. Create and test your changes\n'
                     '4. Create a pull-request\n'
                     '5. Wait for default reviewers to review and merge your '
                     'PR\n'
                     '\n'
                     '## Running tests\n'
                     'Tests are run on docker by executing\n'
                     '```shell\n'
                     '$ make test\n'
                     '```\n'
                     '\n'
                     'Or using venv\n'
                     '```shell\n'
                     '$ make test_local\n'
                     '```\n'
                     '\n'
                     '## Versioning\n'
                     '\n'
                     'We use SemVer 2 for versioning. For the versions '
                     'available, see the tags on this \n'
                     'repository.\n'
                     '\n'
                     '## Authors\n'
                     '* *KPN I&P D-Nitro* - d-nitro@kpn.com\n',
 'long_description_content_type': 'text/markdown',
 'name': 'katka-core',
 'packages': ['katka',
              'tests',
              'katka.migrations',
              'tests.utils',
              'tests.unit',
              'tests.unit.migrations'],
 'tests_require': ['tox'],
 'url': 'https://github.com/kpn/katka-core',
 'version': '0.28.0',
 'zip_safe': False})
